import { RequiredBy, PropTypes, DirectionProperty, CommonProperties, Context, NormalizeProps } from '@zag-js/types';
import * as _zag_js_core from '@zag-js/core';
import { StateMachine } from '@zag-js/core';

type ElementIds = Partial<{
    button: string;
}>;
type PublicContext = DirectionProperty & CommonProperties & {
    /**
     * The ids of the elements in the toggle. Useful for composition.
     */
    ids?: ElementIds;
    /**
     * Specifies the localized strings that identifies the accessibility elements and their states
     */
    "aria-label": string;
    /**
     * Whether the toggle is disabled.
     */
    disabled?: boolean;
    /**
     * Function to call when the toggle is clicked.
     */
    onChange?: (details: {
        pressed: boolean;
    }) => void;
    /**
     * Whether the toggle is initially pressed.
     */
    pressed: boolean;
};
type UserDefinedContext = RequiredBy<PublicContext, "id">;
type ComputedContext = Readonly<{}>;
type PrivateContext = Context<{}>;
type MachineContext = PublicContext & PrivateContext & ComputedContext;
type MachineState = {
    value: "ready";
};
type State = StateMachine.State<MachineContext, MachineState>;
type Send = StateMachine.Send<StateMachine.AnyEventObject>;
type MachineApi<T extends PropTypes = PropTypes> = {
    /**
     * Whether the toggle is pressed.
     */
    isPressed: boolean;
    /**
     * Function to set the pressed state of the toggle.
     */
    setPressed(pressed: boolean): void;
    buttonProps: T["button"];
};

declare function connect<T extends PropTypes>(state: State, send: Send, normalize: NormalizeProps<T>): MachineApi<T>;

declare function machine(userContext: UserDefinedContext): _zag_js_core.Machine<MachineContext, MachineState, _zag_js_core.StateMachine.AnyEventObject>;

export { MachineApi as Api, UserDefinedContext as Context, connect, machine };
